<?php
namespace Pinpoint\BlankProduct\Plugin\Model;

use \Magento\Framework\Registry;
use \Magento\Backend\Model\Auth\Session as AuthSession;

/**
 * Class StockRegistryStoragePlugin
 * @package Pinpoint\BlankProduct\Plugin\Model
 */
class StockRegistryStoragePlugin
{
    /**
     * @var Registry
     */
    protected $_coreRegistry;

    /**
     * @var AuthSession
     */
    protected $_authSession;

    /**
     * @var \Pinpoint\BlankProduct\Helper\Quantity
     */
    protected $quantityHelper;

    /**
     * StockRegistryStoragePlugin constructor.
     * @param Registry $coreRegistry
     * @param AuthSession $authSession
     * @param \Pinpoint\BlankProduct\Helper\Quantity $quantityHelper
     */
    public function __construct(
        Registry $coreRegistry,
        AuthSession $authSession,
        \Pinpoint\BlankProduct\Helper\Quantity $quantityHelper
    ) {
        $this->_coreRegistry = $coreRegistry;
        $this->_authSession = $authSession;
        $this->quantityHelper = $quantityHelper;
    }

    /**
     * @param \Magento\CatalogInventory\Model\StockRegistryStorage $subject
     * @param $productId
     * @param $scopeId
     * @param \Magento\CatalogInventory\Api\Data\StockItemInterface $value
     */
    public function beforeSetStockItem(
        \Magento\CatalogInventory\Model\StockRegistryStorage $subject,
        $productId,
        $scopeId,
        \Magento\CatalogInventory\Api\Data\StockItemInterface $value
    ) {
        if(!$this->_authSession->isLoggedIn()) {
            if ($this->_coreRegistry->registry('stockitem_lookup') !== 'value') {
                $this->_coreRegistry->register('stockitem_lookup', 'value');
                $stockItem = $this->quantityHelper->getBlankProductStockItem($productId, true);
                if($stockItem) {
                    $value['qty'] += $stockItem->getQty();
                }
                $this->_coreRegistry->unregister('stockitem_lookup');
            }
        }
    }
}